#[non_exhaustive]pub enum ChildWorkflowCancellationPolicy {
RequestCancellation,
Abandon,
}Expand description
Action applied to an open child when its parent enters cancellation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RequestCancellation
Request cleanup-aware cancellation and keep the parent cancelling until the child reaches a durable terminal outcome.
Abandon
Leave the child independent and allow the parent to finish cancelling.