#[non_exhaustive]pub enum FlowTask {
DriveRun {
run_id: String,
},
ResumeWait {
run_id: String,
wait_id: String,
},
ResumeHook {
run_id: String,
hook_id: String,
payload: JsonValue,
},
ResumeHookByToken {
token: String,
payload: JsonValue,
},
SendSignal {
run_id: String,
signal: WorkflowSignal,
},
DisposeHook {
run_id: String,
hook_id: String,
},
DisposeHookByToken {
token: String,
},
ResumeScheduledRun {
run_id: String,
now: DateTime<Utc>,
},
ResumeDueWaits {
now: DateTime<Utc>,
},
ResumeDueRetries {
now: DateTime<Utc>,
},
}Expand description
Queueable unit of workflow engine work.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DriveRun
Replays a run until it suspends or reaches a terminal state.
ResumeWait
Completes one durable timer wait and replays its run.
ResumeHook
Delivers a payload to a hook addressed within a run.
Fields
ResumeHookByToken
Delivers a payload to a hook addressed by its bearer token.
Fields
SendSignal
Delivers one named asynchronous signal to a run.
Fields

signal: WorkflowSignalCaller-identified signal delivery.
DisposeHook
Closes a hook without delivering a payload.
DisposeHookByToken
Closes a hook addressed by its bearer token.
ResumeScheduledRun
Drives due waits and retries for one targeted run.
Fields
ResumeDueWaits
Compatibility task that scans all runs for due timer waits.
ResumeDueRetries
Compatibility task that scans all runs for due delayed retries.
Implementations