#[non_exhaustive]pub enum RetryBackoff {
Fixed,
Exponential,
}Expand description
Delay progression used between durable step attempts.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fixed
Reuse the same delay after every failed attempt.
Exponential
Double the delay cap after each failed attempt and select a stable, full-jitter delay from the run, step, and attempt identities.