#[non_exhaustive]pub enum WorkflowDslCompatibility {
Compatible,
CompatibleWithWarnings,
RequiresConfirmation,
}Expand description
Compatibility of an imported workflow DSL with the version exercised by this release of A3S Flow.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Compatible
The imported DSL can be consumed directly.
CompatibleWithWarnings
The imported DSL is from an older minor and should surface a warning.
RequiresConfirmation
A newer DSL or different major requires an explicit host decision.