#[non_exhaustive]pub enum WorkflowDslError {
DocumentTooLarge {
actual_bytes: usize,
maximum_bytes: usize,
},
InvalidYaml {
message: String,
},
InvalidJson {
message: String,
},
InvalidDocument {
message: String,
},
InvalidGraph {
message: String,
},
Serialization {
message: String,
},
}Expand description
Failure returned while parsing, validating, planning, or encoding workflow DSL.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DocumentTooLarge
The source exceeds the bounded parser input size.
Fields
InvalidYaml
YAML syntax or data conversion is invalid.
InvalidJson
JSON syntax or data conversion is invalid.
InvalidDocument
Document-level metadata or compatibility is invalid.
InvalidGraph
The DAG cannot produce a valid deterministic execution plan.
Serialization
A validated document or graph could not be serialized.