Execution handle and state types.
ExecutionState is the public snapshot of a workflow execution.
[ExecutionHandle] is an internal struct held by [FlowEngine] to control
a running execution via a signal channel and a cancellation token.
Enums
- Execution
State - Snapshot of a workflow execution’s current lifecycle state.