#[non_exhaustive]pub struct ChildWorkflowCommand {
pub child_id: String,
pub spec: WorkflowSpec,
pub input: JsonValue,
pub cancellation_policy: ChildWorkflowCancellationPolicy,
}Expand description
First-class child workflow definition returned as part of a durable batch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.child_id: StringReplay-stable parent-local child identifier.
spec: WorkflowSpecWorkflow definition used to create the child.
input: JsonValueInitial JSON input supplied to the child.
cancellation_policy: ChildWorkflowCancellationPolicyPolicy applied when the parent is cancelled or terminated.
Implementations
Sourceimpl ChildWorkflowCommand
impl ChildWorkflowCommand
Sourcepub fn new(
child_id: impl Into<String>,
spec: WorkflowSpec,
input: JsonValue,
) -> Self
pub fn new( child_id: impl Into<String>, spec: WorkflowSpec, input: JsonValue, ) -> Self
Create a child definition with the default cancellation policy.
Sourcepub fn with_cancellation_policy(
self,
cancellation_policy: ChildWorkflowCancellationPolicy,
) -> Self
pub fn with_cancellation_policy( self, cancellation_policy: ChildWorkflowCancellationPolicy, ) -> Self
Replace the policy applied when the parent stops.