#[non_exhaustive]pub struct ChildWorkflowSnapshot {
pub child_id: String,
pub run_id: String,
pub spec: WorkflowSpec,
pub input: JsonValue,
pub cancellation_policy: ChildWorkflowCancellationPolicy,
pub requested_at: DateTime<Utc>,
pub requested_sequence: u64,
pub outcome: Option<WorkflowTerminalOutcome>,
pub resolved_at: Option<DateTime<Utc>>,
pub resolved_sequence: Option<u64>,
}Expand description
Parent-owned projection of one first-class child workflow execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.child_id: StringReplay-stable parent-local identity of the child.
run_id: StringGlobally addressable Flow run identifier assigned to the child.
spec: WorkflowSpecImmutable workflow definition used to create the child.
input: JsonValueInitial JSON input supplied to the child.
cancellation_policy: ChildWorkflowCancellationPolicyPolicy applied when the parent is cancelled or terminated.
requested_at: DateTime<Utc>UTC time at which the request was persisted.
requested_sequence: u64Event sequence that recorded the request.
outcome: Option<WorkflowTerminalOutcome>Terminal child outcome observed by the parent.
resolved_at: Option<DateTime<Utc>>UTC time at which the terminal outcome was recorded.
resolved_sequence: Option<u64>Event sequence that recorded the terminal outcome.
Implementations