#[non_exhaustive]pub struct FlowHistoryRetentionReport {
pub deleted_run_ids: Vec<String>,
pub held_run_ids: Vec<String>,
pub referenced_run_ids: Vec<String>,
pub non_terminal_run_ids: Vec<String>,
pub recent_terminal_run_ids: Vec<String>,
}Expand description
Detailed result of a terminal-history retention scan.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.deleted_run_ids: Vec<String>Histories deleted by this scan.
held_run_ids: Vec<String>Eligible histories retained because they have an audit hold.
referenced_run_ids: Vec<String>Eligible histories retained because another linked history is ineligible.
non_terminal_run_ids: Vec<String>Candidate histories retained because their runs are not terminal.
recent_terminal_run_ids: Vec<String>Terminal candidate histories that have not reached the cutoff.