pub struct FlowTaskLease {
pub lease_id: String,
pub task: FlowTask,
}Expand description
Leased task returned by a queue worker before acknowledgement.
Fields
lease_id: Stringtask: FlowTaskTrait Implementations
Sourceimpl Clone for FlowTaskLease
impl Clone for FlowTaskLease
Sourcefn clone(&self) -> FlowTaskLease
fn clone(&self) -> FlowTaskLease
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowTaskLease
impl Debug for FlowTaskLease
Sourceimpl<'de> Deserialize<'de> for FlowTaskLease
impl<'de> Deserialize<'de> for FlowTaskLease
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FlowTaskLease
impl PartialEq for FlowTaskLease
Sourcefn eq(&self, other: &FlowTaskLease) -> bool
fn eq(&self, other: &FlowTaskLease) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FlowTaskLease
impl Serialize for FlowTaskLease
impl StructuralPartialEq for FlowTaskLease