#[non_exhaustive]pub struct FlowTaskOutcome {
pub task: FlowTask,
pub run_ids: Vec<String>,
pub resumed_waits: Vec<(String, String)>,
pub resumed_retries: Vec<(String, String)>,
pub resumed_hook: Option<(String, String)>,
pub disposed_hook: Option<(String, String)>,
pub delivered_signal: Option<(String, String)>,
}Expand description
Result of handling one queued FlowTask.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task: FlowTaskTask whose durable effects are summarized.
run_ids: Vec<String>Runs affected while handling this task.
Run-targeted tasks report the active continuation leaf. Compatibility-wide scan tasks retain their legacy scan and commit-report semantics.
resumed_waits: Vec<(String, String)>Wait completions committed by this task.
resumed_retries: Vec<(String, String)>Delayed retry wakeups driven by this task.
resumed_hook: Option<(String, String)>Hook receipt committed by this task, excluding matching redelivery.
disposed_hook: Option<(String, String)>Hook disposal committed by this task, excluding matching redelivery.
delivered_signal: Option<(String, String)>Signal receipt committed by this task, excluding matching redelivery.