pub struct NativeTsRuntimePreflight {
pub entrypoint: PathBuf,
pub artifact: PathBuf,
pub source_hash: String,
pub cache_hit: bool,
}Expand description
Result of validating and compiling a native TypeScript workflow source.
Fields
entrypoint: PathBufResolved workflow source entrypoint used by the compiler.
artifact: PathBufResolved native artifact path that will be invoked by the runtime.
source_hash: StringStable hash of the workflow source and runtime identity fields.
cache_hit: boolTrue when the existing artifact cache entry was reused.