#[non_exhaustive]pub struct StepInvocation {
pub run_id: String,
pub step_id: String,
pub step_name: String,
pub input: JsonValue,
pub history: Vec<FlowEventEnvelope>,
}Expand description
Step execution request passed to a runtime implementation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.run_id: StringDurable identifier of the workflow run that scheduled the step.
step_id: StringReplay-stable identifier of this step invocation.
step_name: StringHost-defined step handler name.
input: JsonValueInput supplied by the workflow command.
history: Vec<FlowEventEnvelope>Complete persisted workflow history in sequence order.
Implementations
Sourceimpl StepInvocation
impl StepInvocation
Sourcepub fn new(
run_id: impl Into<String>,
step_id: impl Into<String>,
step_name: impl Into<String>,
input: JsonValue,
history: Vec<FlowEventEnvelope>,
) -> Self
pub fn new( run_id: impl Into<String>, step_id: impl Into<String>, step_name: impl Into<String>, input: JsonValue, history: Vec<FlowEventEnvelope>, ) -> Self
Create a step invocation from its complete durable execution input.
Sourcepub fn input_as<T>(&self) -> Result<T>where
T: DeserializeOwned,
pub fn input_as<T>(&self) -> Result<T>where
T: DeserializeOwned,
Decode the step input into a host-defined serde type.