pub struct WorkflowDagEdge { /* private fields */ }Expand description
One directed connection between workflow DAG nodes.
Implementations
Sourceimpl WorkflowDagEdge
impl WorkflowDagEdge
Sourcepub fn new(
id: impl Into<String>,
source: impl Into<String>,
target: impl Into<String>,
) -> Self
pub fn new( id: impl Into<String>, source: impl Into<String>, target: impl Into<String>, ) -> Self
Construct a directed edge between two node identities.
Sourcepub fn with_source_handle(self, source_handle: impl Into<String>) -> Self
pub fn with_source_handle(self, source_handle: impl Into<String>) -> Self
Sets the source connector handle used by the authoring canvas.
Sourcepub fn with_target_handle(self, target_handle: impl Into<String>) -> Self
pub fn with_target_handle(self, target_handle: impl Into<String>) -> Self
Sets the target connector handle used by the authoring canvas.
Sourcepub fn source_handle(&self) -> Option<&str>
pub fn source_handle(&self) -> Option<&str>
Returns the optional source connector handle.
Sourcepub fn target_handle(&self) -> Option<&str>
pub fn target_handle(&self) -> Option<&str>
Returns the optional target connector handle.
Sourcepub fn presentation(&self) -> &BTreeMap<String, Value>
pub fn presentation(&self) -> &BTreeMap<String, Value>
Returns presentation-only fields preserved during round trips.