#[non_exhaustive]pub struct WorkflowInvocation {
pub run_id: String,
pub spec: WorkflowSpec,
pub input: JsonValue,
pub history: Vec<FlowEventEnvelope>,
}Expand description
Workflow replay request passed to a runtime implementation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.run_id: StringDurable identifier of the workflow run being replayed.
spec: WorkflowSpecWorkflow definition recorded when the run was created.
input: JsonValueOriginal workflow input.
history: Vec<FlowEventEnvelope>Complete persisted event history in sequence order.
Implementations
Sourceimpl WorkflowInvocation
impl WorkflowInvocation
Sourcepub fn new(
run_id: impl Into<String>,
spec: WorkflowSpec,
input: JsonValue,
history: Vec<FlowEventEnvelope>,
) -> Self
pub fn new( run_id: impl Into<String>, spec: WorkflowSpec, input: JsonValue, history: Vec<FlowEventEnvelope>, ) -> Self
Create a workflow invocation from its complete durable replay input.
Sourcepub fn context(&self) -> WorkflowContext<'_>
pub fn context(&self) -> WorkflowContext<'_>
Build a deterministic helper view over this workflow invocation.
Sourcepub fn input_as<T>(&self) -> Result<T>where
T: DeserializeOwned,
pub fn input_as<T>(&self) -> Result<T>where
T: DeserializeOwned,
Decode the workflow input into a host-defined serde type.