#[non_exhaustive]pub struct WorkflowSignal {
pub signal_id: String,
pub name: String,
pub payload: JsonValue,
}Expand description
One durable asynchronous message delivered to a workflow execution.
signal_id is the caller-owned idempotency identity. A caller must reuse
both the target run ID and this value when retrying an uncertain delivery.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.signal_id: StringCaller-owned idempotency identity.
name: StringDeclared signal contract name.
payload: JsonValueApplication-defined JSON payload.
Implementations