pub trait FlowEventObserver: Send + Sync {
// Required method
fn observe<'life0, 'async_trait>(
&'life0 self,
envelope: FlowEventEnvelope,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Observer for committed workflow events.
Observers run after the event has been appended to the durable store. They must not be treated as the source of truth for workflow state.
Required Methods
fn observe<'life0, 'async_trait>(
&'life0 self,
envelope: FlowEventEnvelope,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".