pub struct FlowScheduler { /* private fields */ }Expand description
Scheduler that scans durable state and enqueues due workflow work.
Implementations
Sourceimpl FlowScheduler
impl FlowScheduler
pub fn new(engine: FlowEngine, queue: Arc<dyn FlowTaskQueue>) -> Self
pub fn engine(&self) -> &FlowEngine
pub fn queue(&self) -> Arc<dyn FlowTaskQueue>
Sourcepub async fn next_wakeup(
&self,
now: DateTime<Utc>,
) -> Result<Option<WorkflowRunSuspension>>
pub async fn next_wakeup( &self, now: DateTime<Utc>, ) -> Result<Option<WorkflowRunSuspension>>
Return the earliest wait or delayed retry that can wake the scheduler.
Sourcepub async fn next_wakeup_delay(
&self,
now: DateTime<Utc>,
) -> Result<Option<Duration>>
pub async fn next_wakeup_delay( &self, now: DateTime<Utc>, ) -> Result<Option<Duration>>
Return how long the host can sleep before the next scheduled wake-up.
Due or overdue wake-ups return Duration::ZERO. Active hooks are not
represented because external callbacks are pushed into the queue by the
callback router instead of time.
pub async fn enqueue_due_work( &self, now: DateTime<Utc>, ) -> Result<FlowSchedulerTick>