pub struct NativeTsRuntime { /* private fields */ }Expand description
Runtime that compiles TypeScript to a native executable and speaks JSON over stdin/stdout with that executable.
Implementations
Sourceimpl NativeTsRuntime
impl NativeTsRuntime
Sourcepub const DEFAULT_MAX_STDOUT_BYTES: usize
pub const DEFAULT_MAX_STDOUT_BYTES: usize
Default maximum bytes retained from a compiler or runtime stdout pipe.
Sourcepub const DEFAULT_MAX_STDERR_BYTES: usize
pub const DEFAULT_MAX_STDERR_BYTES: usize
Default maximum bytes retained from a compiler or runtime stderr pipe.
pub fn new(config: NativeTsRuntimeConfig) -> Self
pub fn config(&self) -> &NativeTsRuntimeConfig
Sourcepub fn with_output_limits(
self,
max_stdout_bytes: usize,
max_stderr_bytes: usize,
) -> Self
pub fn with_output_limits( self, max_stdout_bytes: usize, max_stderr_bytes: usize, ) -> Self
Override the independent byte limits for each compiler and runtime stdout/stderr pipe.
Exceeding either limit terminates the direct child process and returns a runtime error. A zero limit allows an empty pipe but rejects its first byte of output.
Sourcepub fn max_stdout_bytes(&self) -> usize
pub fn max_stdout_bytes(&self) -> usize
Return the configured byte limit for each stdout pipe.
Sourcepub fn max_stderr_bytes(&self) -> usize
pub fn max_stderr_bytes(&self) -> usize
Return the configured byte limit for each stderr pipe.
pub async fn preflight( &self, spec: &WorkflowSpec, ) -> Result<NativeTsRuntimePreflight>