#[non_exhaustive]pub struct WorkflowSpec {
pub name: String,
pub version: String,
pub runtime: RuntimeSpec,
pub runtime_build_id: Option<RuntimeBuildId>,
pub patch_markers: BTreeSet<WorkflowPatchId>,
pub signal_names: BTreeSet<String>,
}Expand description
Durable workflow definition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringStable workflow type name used for registration and inspection.
version: StringApplication-defined workflow definition version.
runtime: RuntimeSpecRuntime entrypoint used to replay the workflow.
runtime_build_id: Option<RuntimeBuildId>Exact deployed runtime build required to replay this run.
patch_markers: BTreeSet<WorkflowPatchId>Replay-safe code changes enabled for this run at creation time.
signal_names: BTreeSet<String>Named asynchronous message contracts accepted by this workflow.
Implementations
Sourceimpl WorkflowSpec
impl WorkflowSpec
Sourcepub fn native_ts(
name: impl Into<String>,
version: impl Into<String>,
entrypoint: impl Into<String>,
export_name: impl Into<String>,
) -> Self
pub fn native_ts( name: impl Into<String>, version: impl Into<String>, entrypoint: impl Into<String>, export_name: impl Into<String>, ) -> Self
Creates a workflow definition backed by native TypeScript.
Sourcepub fn rust_embedded(
name: impl Into<String>,
version: impl Into<String>,
entrypoint: impl Into<String>,
export_name: impl Into<String>,
) -> Self
pub fn rust_embedded( name: impl Into<String>, version: impl Into<String>, entrypoint: impl Into<String>, export_name: impl Into<String>, ) -> Self
Creates a workflow definition backed by an embedded Rust runtime.
Sourcepub fn with_runtime_build(self, runtime_build_id: RuntimeBuildId) -> Self
pub fn with_runtime_build(self, runtime_build_id: RuntimeBuildId) -> Self
Pin new runs to the exact runtime build that can replay them.
Sourcepub fn with_patch_marker(self, patch_id: WorkflowPatchId) -> Self
pub fn with_patch_marker(self, patch_id: WorkflowPatchId) -> Self
Enable a replay-safe code path for every run created from this spec.
The complete marker set is persisted atomically inside run_created.
Reusing an existing run ID with a different set is rejected as a start
conflict instead of changing the behavior of an in-flight history.
Sourcepub fn has_patch_marker(&self, patch_id: &str) -> bool
pub fn has_patch_marker(&self, patch_id: &str) -> bool
Return whether this immutable run definition contains patch_id.
Sourcepub fn with_signal(self, signal_name: impl Into<String>) -> Self
pub fn with_signal(self, signal_name: impl Into<String>) -> Self
Declare one named asynchronous signal contract for this workflow.
Sourcepub fn accepts_signal(&self, signal_name: &str) -> bool
pub fn accepts_signal(&self, signal_name: &str) -> bool
Return whether this immutable workflow definition accepts signal_name.